//!	Arduino_AnalogOutput.h


//--------------------------- inclusion guards ----------------------
#ifndef _Arduino_AnalogOutput_h_
#define _Arduino_AnalogOutput_h_


//--------------------------- include section -----------------------
#include "EOS_AnalogOutput.h"
#include "Arduino.h"


//--------------------------- class definition ----------------------
//! this class represents an abstraction of an analog output used
//! with an Arduino board
//! \code
//! class CPin3 :
//!         public CArduino_DigitalInput<3>,
//!         public CArduino_DigitalOutput<3>,
//!         public CArduino_AnalogOutput<3,255>
//! \endcode
template <int PIN, int RESOLUTION>
class CArduino_AnalogOutput :
        public CEOS_AnalogOutput
{
//--------------------------- construction --------------------------
public:
    // constructor --------------------------------------------------
    //! \internal
    CONSTRUCTOR_EMPTY_NO_COPY_AND_ASSIGNMENT(CArduino_AnalogOutput);


//--------------------------- public access -------------------------
public:
    // operator = ---------------------------------------------------
    inline void operator = (unsigned int nValue)
    {
        writeAnalog(nValue);
    }

    // toAnalogOutput -----------------------------------------------
    //! uses the Arduino function pinMode(pin,mode)
    inline virtual void toAnalogOutput()
    {
        pinMode(PIN,OUTPUT);
    }

    // getAnalogOutputResolution ------------------------------------
    inline virtual unsigned int getAnalogOutputResolution() const
    {
        return RESOLUTION;
    }

    // writeAnalog --------------------------------------------------
    //! uses the Arduino function analogWrite(pin,value)
    inline virtual void writeAnalog(unsigned int nValue)
    {
        analogWrite(PIN,nValue);
    }

};


#endif
