//!	EOS_DigitalOutput.h


//--------------------------- inclusion guards ----------------------
#ifndef _EOS_DigitalOutput_h_
#define _EOS_DigitalOutput_h_


//--------------------------- include section -----------------------
#include "types.h"
#include "EOS_DigitalInput.h"


//--------------------------- class definition ----------------------
//! this class represents an abstraction of a digital output
//! \code
//! class CPin :
//!     public CEOS_DigitalInput
//! \endcode
class CEOS_DigitalOutput
{
//--------------------------- construction --------------------------
public:
    // constructor --------------------------------------------------
    CONSTRUCTOR_EMPTY_NO_COPY_AND_ASSIGNMENT(CEOS_DigitalOutput);


//--------------------------- public access -------------------------
public:
    // operator = ---------------------------------------------------
    //! writes the boolean value to the port pin\n
    //! uses the function writeDigital()
    //! \param bActive is the value that will be written to the output
    inline void operator = (bool_t bActive)
    {
        writeDigital(bActive);
    }

    // operator = ---------------------------------------------------
    //! copies the value of the input to this output\n
    //! uses the function writeDigital()
    inline void operator = (CEOS_DigitalInput& EOS_DigitalInput)
    {
        writeDigital(EOS_DigitalInput.readDigital());
    }


//--------------------------- public virtual access -----------------
public:
    // toDigitalOutput ----------------------------------------------
    //! switches the data direction registers to be an digital output\n
    //! This is a pure virtual function and needs to be implemented
    //! in the derived classes according the µC datasheet
    virtual void toDigitalOutput() = 0;

    // writeOutput --------------------------------------------------
    //! writes the given value to the port pin\n
    //! This is a pure virtual function and needs to be implemented
    //! in the derived classes according the µC datasheet
    virtual void writeDigital(bool_t bActive) = 0;
};


#endif
