//!	EOS_PullUpResistor.h


//--------------------------- inclusion guards ----------------------
#ifndef _EOS_PullUpResistor_h_
#define _EOS_PullUpResistor_h_


//--------------------------- include section -----------------------
#include "types.h"


//--------------------------- class definition ----------------------
//! this class represents an abstraction of a pin, that has a
//! switchable pull down pin
//! \code
//! class CPin :
//!     public CEOS_PullUpResistor
//! \endcode
class CEOS_PullUpResistor
{
//--------------------------- construction --------------------------
public:
    // constructor --------------------------------------------------
    CONSTRUCTOR_EMPTY_NO_COPY_AND_ASSIGNMENT(CEOS_PullUpResistor);


//--------------------------- public virtual access -----------------
public:
    // setPullUpResistor ------------------------------------------
    //! switches on/off the pull down resistor on this pin
    //! \param bEnabled is true for switching on the resistor, false
    //! otherwise
    //! \code
    //! GPIO13.setPullUpResistor(true);
    //! \endcode
    virtual void setPullUpResistor(bool bEnabled) = 0;

    // enablePullUpResistor ---------------------------------------
    //! switches on the pull down resistor on this pin
    //! \code
    //! GPIO13.enablePullUp();
    //! \endcode
    inline void enablePullUpResistor()
    {
        setPullUpResistor(true);
    }

    // disablePullUpResistor --------------------------------------
    //! switches off the pull down resistor on this pin
    //! \code
    //! GPIO13.disablePullUp();
    //! \endcode
    inline void disablePullUpResistor()
    {
        setPullUpResistor(false);
    }
};


#endif
