//!	EOS_Timer.h


//--------------------------- inclusion guards ----------------------
#ifndef _EOS_Timer_h_
#define _EOS_Timer_h_


//--------------------------- include section -----------------------
#include "EOS_Event.h"


//--------------------------- class definition ----------------------
//! CEOS_Timer represents a timer of the MCU
//! \code
//! class CTimer0 :
//!     public CEOS_Timer
//! \endcode
class CEOS_Timer
{
//--------------------------- construction --------------------------
public:
    // constructor --------------------------------------------------
    //! \internal
    CONSTRUCTOR_EMPTY_NO_COPY_AND_ASSIGNMENT(CEOS_Timer);


//--------------------------- public virtual access -----------------
public:
    // initialize ---------------------------------------------------
    //! sets the timer to overflow after nTimeout
    //! \param nTimeout is the time in ms after the timer shall
    //! overflow
    //! \return true, if the given timeout is valid and can be used\n
    //!         false otherwise
    virtual bool_t initialize(unsigned int nTimeout) = 0;

    // start --------------------------------------------------------
    //! starts the timer
    virtual void start() = 0;


//--------------------------- public data ---------------------------
public:
    // m_EventOverflow ----------------------------------------------
    //! when the timer overflows this event will be triggered
    CEOS_Event<> m_EventOverflow;
};


#endif
