//	Stack.h
//  this file handles a Stack


//--------------------------- inclusion guards ----------------------
#ifndef _Stack_h_
#define	_Stack_h_


//--------------------------- include section -----------------------
#include "types.h"


//--------------------------- class definition ----------------------
template <class T_DATA, class T_POS, int N_SIZE> class CStack
{
//--------------------------- construction --------------------------
public:
    // Constructor --------------------------------------------------
    inline CStack() :
        m_nItems(0)
    {
        // Nothing else to do
    }

    // Destructor ---------------------------------------------------
    inline ~CStack()
    {
        // Nothing to do
    }

    // lock copy and assignement ------------------------------------
private:
    CStack(const CStack& Stack);
    const CStack& operator = (const CStack& Stack);


//--------------------------- public access -------------------------
public:
    // addItem ------------------------------------------------------
    bool_t addItem(const T_DATA& vData)
    {
        if (!isFull())
        {
            m_DataArray[m_nItems] = vData;
            m_nItems++;
            return true;
        }
        return false;
    }

    // accessItem ---------------------------------------------------
    inline T_DATA& accessItem(T_POS nPos)
    {
        return m_DataArray[m_nItems - nPos];
    }

    // removeItem ---------------------------------------------------
    inline void removeItem()
    {
        m_nItems--;
    }

    // getItem ------------------------------------------------------
    inline T_DATA getItem()
    {
        removeItem();
        return m_DataArray[m_nItems];
    }

    // items --------------------------------------------------------
    inline T_POS items() const
    {
        return m_nItems;
    }

    // isEmpty ------------------------------------------------------
    inline bool_t isEmpty()
    {
        return (m_nItems == 0);
    }

    // isFull -------------------------------------------------------
    inline bool_t isFull()
    {
        return (m_nItems >= N_SIZE);
    }


//--------------------------- protected data ------------------------
protected:
    // m_DataArray --------------------------------------------------
    T_DATA m_DataArray[N_SIZE];

    // m_nItems -----------------------------------------------------
    T_POS m_nItems;

};


//--------------------------- derived classes -----------------------
template<class T_DATA,int N_SIZE> class CStack8 : public CStack<T_DATA,uint8,N_SIZE>{};
template<class T_DATA,int N_SIZE> class CStack16 : public CStack<T_DATA,uint16,N_SIZE>{};
template<class T_DATA,int N_SIZE> class CStack32 : public CStack<T_DATA,uint32,N_SIZE>{};



#endif  // Inclusion guard

